import unittest
from unittest.mock import patch

import dropbox
import fsspec

import dropboxdrivefs
from dropboxdrivefs import DropboxDriveFileSystem


@patch.object(dropbox.Dropbox, "files_list_folder")
class TestDropboxLs(unittest.TestCase):
    def setUp(self):
        self.fs = DropboxDriveFileSystem("123")

        self.folder_list = dropbox.files.ListFolderResult()
        self.folder_list.entries = [
            dropbox.files.FileMetadata(
                name="file1.txt", path_display="file1.txt", size=20
            ),
            dropbox.files.FileMetadata(
                name="file2.txt", path_display="file2.txt", size=30
            ),
        ]
        self.folder_list.cursor = "123"
        self.folder_list.has_more = False


class TestDropboxOpen(unittest.TestCase):
    def setUp(self):
        self.fs = DropboxDriveFileSystem("123")

    @patch.object(dropbox.Dropbox, "files_get_temporary_link")
    @patch.object(dropboxdrivefs.DropboxDriveFileSystem, "info")
    def test_open_rb(self, moke_info, moke_link):
        import fsspec.implementations.webhdfs

        temp_link = dropbox.files.GetTemporaryLinkResult()
        temp_link.metadata = dropbox.files.FileMetadata(name="file1.txt")
        temp_link.link = "http://test_link"
        moke_link.return_value = temp_link

        moke_info.return_value = {"size": 20}

        reader = self.fs._open("/Home/folder1", mode="rb")

        self.assertIsInstance(reader, fsspec.implementations.webhdfs.WebHDFile)

    def test_open_wb(self):
        with patch("dropboxdrivefs.core.DropboxDriveFile") as mock_subclass:
            reader = self.fs._open("/Home/folder1", mode="wb")
            self.assertIsInstance(reader, type(mock_subclass.return_value))


class TestMetadata(unittest.TestCase):
    def setUp(self):
        self.fs = DropboxDriveFileSystem("123")
        self.metadata = [
            dropbox.files.FileMetadata(
                name="file1.txt", path_display="file1.txt", size=20
            ),
            dropbox.files.FolderMetadata(name="files", path_display="files"),
        ]

    def test_info_file(self):
        info = self.fs._refactor_metadata(self.metadata[0])

        self.assertEqual(info["name"], "file1.txt")
        self.assertEqual(info["size"], 20)
        self.assertEqual(info["type"], "file")

    def test_info_folder(self):
        info = self.fs._refactor_metadata(self.metadata[1])

        self.assertEqual(info["name"], "files")
        self.assertEqual(info["size"], None)
        self.assertEqual(info["type"], "directory")

    def test_info(self):
        info = self.fs._refactor_metadata(
            dropbox.files.Metadata(name="file1.txt", path_display="file1.txt")
        )
        self.assertEqual(info["name"], "file1.txt")
        self.assertEqual(info["size"], None)
        self.assertEqual(info["type"], None)

    def test_info_no_details(self):
        info = self.fs._refactor_metadata(self.metadata[0], detail=False)

        self.assertEqual(info, "file1.txt")


if __name__ == "__main__":
    unittest.main()



from os import path

from setuptools import setup

here = path.abspath(path.dirname(__file__))
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="dropboxdrivefs",
    version="1.3.1",
    packages=["dropboxdrivefs"],
    install_requires=["fsspec", "requests", "dropbox"],
    author="Marine Chaput",
    author_email="marine.chaput@hotmail.fr",
    url = "https://github.com/fsspec/dropboxdrivefs",
    description="Dropbox implementation for fsspec module",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",

    ],
    python_requires=">=3.5",
    license="BSD",
    zip_safe=False,
)
